@@ -19,7 +19,7 @@ def before_all():
     tests_project_path = str(Path(__file__).parent.parent.parent) + '/automation-qa-tests-tokensfarm'
 
     # Store the project user directory in pytest global variables
-    pytest.project_dir = tests_project_path
+    pytest.project_dir = infra_project_path
     pytest.user_dir = infra_project_path
 
     # Specify path
